==> bsflite-0.80.tar.gz: bsflite-0.80/out.c <==
/**
 ** bsflite - bs-free AIM client
 **
 ** (C) 2003-2005 by Claudio Leite <leitec at leitec dot org>
 **
 ** NO WARRANTY. Read the file COPYING for more details.
 **/

#include "bsf.h"
#include <stdio.h>
#include <sys/time.h>
#ifdef PLAN9
#include <time.h>
#endif
#include <stdlib.h>
#include <string.h>

#ifdef __MINGW32__
#include <windows.h>
#else
#include <termios.h>
#include <sys/ioctl.h>
#endif

#ifdef __DJGPP__
#include <conio.h>
#endif

extern char     inputbuf[512];
extern int      screen_cols;
extern int      screen_lines;
extern int      prompt_len;
extern struct BuddyList *buddylist;
extern struct Conn *conn;

#ifdef __MINGW32__
HANDLE          hOut;
#endif

/* PROTO */
void
addts(void)
{
	char            ts[11];
	struct tm      *now;
	time_t          t;

#ifdef COLOR
	set_color(COLOR_TIMESTAMP);
#endif

	t = time(0);
	now = localtime(&t);
	strftime(ts, 11, "[%H:%M:%S]", now);
	printf("%s", ts);

#ifdef COLOR
	set_color(0);
#endif
	return;
}

#if !defined(PLAN9)
#define TERMINAL_HIJINX
#endif

#ifdef TERMINAL_HIJINX

#ifdef __MINGW32__
#define TERMINAL_WINDOWS
#else

#ifdef __DJGPP__
#define TERMINAL_CONIO
#else
#define TERMINAL_VT100
#endif

#endif

#endif

/* PROTO */
void
eraseline(void)
{
	int             linelen = strlen(inputbuf) + prompt_len;
#ifdef TERMINAL_HIJINX
	int             numcols, numrows, x;
#ifdef TERMINAL_CONIO
	int             desiredx, desiredy;
#endif

#ifdef TERMINAL_WINDOWS
	COORD           nPos;
	CONSOLE_SCREEN_BUFFER_INFO wInfo;
	get_screen_size();
#endif

	numrows = linelen / screen_cols;
	numcols = linelen % screen_cols;

#ifdef TERMINAL_VT100
	if (numrows > 0)
		printf("\033[%dA", numrows);

	if (numcols > 0)
		printf("\033[%dD", numcols);
#endif
#ifdef TERMINAL_WINDOWS
	GetConsoleScreenBufferInfo(hOut, &wInfo);

	nPos.X = wInfo.dwCursorPosition.X - numcols;
	nPos.Y = wInfo.dwCursorPosition.Y - numrows;

	SetConsoleCursorPosition(hOut, nPos);
#endif

#ifdef TERMINAL_CONIO
	desiredx = wherex() - numcols;
	desiredy = wherey() - numrows;

	gotoxy(desiredx, desiredy);
#endif

	for (x = 0; x < linelen; x++)
		putchar(' ');

#ifdef TERMINAL_VT100
	if (numrows > 0)
		printf("\033[%dA", numrows);

	if (numcols > 0)
		printf("\033[%dD", numcols);
#endif
#ifdef TERMINAL_WINDOWS
	GetConsoleScreenBufferInfo(hOut, &wInfo);

	nPos.X = wInfo.dwCursorPosition.X - numcols;
	nPos.Y = wInfo.dwCursorPosition.Y - numrows;

	SetConsoleCursorPosition(hOut, nPos);
#endif
#ifdef TERMINAL_CONIO
	fflush(stdout);

	gotoxy(desiredx, desiredy);
#endif

#else
	int             x;

	for (x = 0; x < linelen; x++)
		printf("\b \b");
#endif

#ifdef COLOR
	set_color(0);
#endif
}

/* PROTO */
void
get_screen_size(void)
{
#if defined(__MINGW32__) || defined(__DJGPP__) || defined(PLAN9)
#ifdef __MINGW32__
	CONSOLE_SCREEN_BUFFER_INFO p;

	GetConsoleScreenBufferInfo(hOut, &p);

	screen_cols = (int) p.dwSize.X;
	screen_lines = (int) p.dwSize.Y;
#endif

#ifdef PLAN9
	screen_cols = getwidth();
	screen_lines = 25;
#endif

#ifdef __DJGPP__
	struct text_info *ti;

	gettextinfo(ti);

	screen_cols = ti->screenwidth;
	screen_lines = ti->screenheight;

	printf("size: %dx%d\n", screen_cols, screen_lines);
#endif
#else
	struct winsize  scrsize;

	ioctl(fileno(stdin), TIOCGWINSZ, &scrsize);
	screen_cols = scrsize.ws_col;
	screen_lines = scrsize.ws_row;
#endif
}

/* PROTO */
void
wordwrap_print(char *str, int offset)
{
	char           *linebuf;
	char           *curline;
	int             firstline = 1;
	int             xx = 0, yy, jj;

#ifdef __MINGW32__
	get_screen_size();
#endif

	linebuf = malloc(screen_cols + 1);
	curline = str;

	for (;;) {
		if (curline[xx] == 0)
			break;
		if (curline[xx] != ' ') {
			xx++;
			continue;
		}
		yy = xx + 1;
		while (curline[yy] != ' ')
			if (curline[yy] == 0)
				break;
			else
				yy++;

		if (yy > (screen_cols - offset - 1)) {
			memset(linebuf, 0, screen_cols + 1);
			strncpy(linebuf, curline, xx);
			if (!firstline) {
				for (jj = 0; jj < offset; jj++)
					putchar(' ');
			} else {
				firstline = 0;
			}

			printf("%s\n", linebuf);
			curline += xx + 1;
			xx = 0;
			continue;
		}
		xx++;
	}

	if (!firstline)
		for (jj = 0; jj < offset; jj++)
			putchar(' ');

	printf("%s\n", curline);
	free(linebuf);
}

/* PROTO */
void
wordwrap_print_echostr(char *str, char *echostr)
{
	char           *linebuf;
	char           *curline;
	int             offset;
	int             xx = 0, yy;

#ifdef __MINGW32__
	get_screen_size();
#endif

	offset = strlen(echostr) + 1;
	linebuf = malloc(screen_cols + 1);
	curline = str;

	for (;;) {
		if (curline[xx] == 0)
			break;
		if (curline[xx] != ' ') {
			xx++;
			continue;
		}
		yy = xx + 1;
		while (curline[yy] != ' ')
			if (curline[yy] == 0)
				break;
			else
				yy++;

		if (yy > (screen_cols - offset - 1)) {
			memset(linebuf, 0, screen_cols + 1);
			strncpy(linebuf, curline, xx);
			printf("%s %s\n", echostr, linebuf);
			curline += xx + 1;
			xx = 0;
			continue;
		}
		xx++;
	}

	printf("%s %s\n", echostr, curline);
	free(linebuf);
}

#ifdef COLOR
/* PROTO */
void
set_color(int color)
{
	int             bd, fg;
#ifdef COLOR_DARKBG
	int             bg;
#endif

	if (color == 0) {
		printf("\E[0m");
		fflush(stdout);
		return;
	}
	bd = color / 100;
	fg = color % 100;
#ifdef COLOR_DARKBG
	bg = (color % 100) / 10;

	printf("\E[%d;3%d;4%dm", bd, fg, bg);
#else
	printf("\E[%d;3%dm", bd, fg);
#endif
	fflush(stdout);
}
#endif

/* PROTO */
void
display_buddylist(void)
{
	struct BuddyList *trav;

	for (trav = buddylist; trav != NULL; trav = trav->next) {
		printf("%s ", BUDDYLIST_ECHOSTR);

		if (trav->idle && trav->away)
			printf("%s", BUDDYLIST_GONE);
		else if (trav->idle)
			printf("%s", BUDDYLIST_IDLE);
		else if (trav->away)
			printf("%s", BUDDYLIST_AWAY);
		else
			printf("%s", BUDDYLIST_ONLINE);

		printf(" %s\n", trav->formattedsn);
	}
}

#define p_echostr() {if(col == 1) printf("%s", BUDDYLIST_ECHOSTR);}

/* PROTO */
void
display_buddylist_sorted(void)
{
	struct BuddyList *trav;
	char            sncopy[17];
	int             run, col;
	int             numcols;


#ifdef __MINGW32__
	get_screen_size();
#endif

	numcols = (screen_cols / 24) - 1;

	if (numcols <= 0)
		numcols = 1;

	for (run = 0, col = 1; run < 4; run++) {
		for (trav = buddylist; trav != NULL; trav = trav->next) {
			if (run == 0) {
				if (!trav->idle && !trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_ONLINE);
				} else {
					continue;
				}
			} else if (run == 1) {
				if (trav->idle && !trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_IDLE);
				} else {
					continue;
				}
			} else if (run == 2) {
				if (!trav->idle && trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_AWAY);
				} else {
					continue;
				}
			} else {
				if (trav->idle && trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_GONE);
				} else {
					continue;
				}
			}

			memset(sncopy, 0, sizeof(sncopy));

			if (strlen(trav->formattedsn) > 16) {
				memcpy(sncopy, trav->formattedsn, 13);
				strcat(sncopy, "...");
			} else {
				memcpy(sncopy, trav->formattedsn, strlen(trav->formattedsn));
			}

			if (col < numcols) {
				printf(" %-16s  ", sncopy);
				col++;
			} else {
				printf(" %s\n", sncopy);
				col = 1;
			}
		}

		if (col != 1)
			printf("\n");

		col = 1;
	}
}

/* PROTO */
void
showAwayMessages(void)
{
	struct BuddyList *trav;
	char          **sns = NULL;
	int             cur = 0, x = 0, num = 0, left = 0, y;

	for (trav = buddylist; trav != NULL; trav = trav->next)
		if (trav->away)
			num++;

	for (trav = buddylist; trav != NULL; trav = trav->next) {
		if (trav->away) {
			if (x == 0) {
				if (num - cur < 5)
					left = num - cur;
				else
					left = 5;

				sns = malloc(left * sizeof(char *));
			}
			sns[x] = strdup(trav->sn);
			x++;
			if (x == left) {
				imcomm_request_massawaymsg(conn->conn, sns, left);
				for (y = 0; y < left; y++)
					free(sns[y]);
				free(sns);
				x = 0;
				cur += left;
				if (cur >= num)
					break;

				printf(".");
				fflush(stdout);
#ifdef __MINGW32__
				Sleep(1000);
#else
				sleep(1);
#endif

			}
		}
	}
}

/* PROTO */
void
printspaces(int num)
{
	int             jj;

	for (jj = 0; jj < num; jj++)
		putchar(' ');
}

/* PROTO */
void
prettyprint(char *ptext, int offset)
{
	int             pos, x;
	char           *ttmp;

	pos = 0;
	while (pos < strlen(ptext)) {
		for (x = pos; x < strlen(ptext); x++) {
			if (x == strlen(ptext) - 1) {
				ttmp = malloc(x - pos + 2);
				strncpy(ttmp, ptext + pos, x - pos + 1);
				if (ttmp[x - pos] == '\n')
					ttmp[x - pos] = 0;

				ttmp[x - pos + 1] = 0;
				if (pos != 0)
					printspaces(offset);

				wordwrap_print(ttmp, offset);
				free(ttmp);
			} else if (ptext[x] == '\n') {
				ttmp = malloc(x - pos + 1);
				strncpy(ttmp, ptext + pos, x - pos);
				ttmp[x - pos] = 0;

				if (pos != 0)
					printspaces(offset);
				wordwrap_print(ttmp, offset);
				free(ttmp);
				break;
			}
		}
		pos = x + 1;
	}
}


/* PROTO */
void
prettyprint_echostr(char *ptext, char *echostr)
{
	int             pos, x;
	char           *ttmp;

	pos = 0;
	while (pos < strlen(ptext)) {
		for (x = pos; x < strlen(ptext); x++) {
			if (x == strlen(ptext) - 1) {
				ttmp = malloc(x - pos + 2);
				strncpy(ttmp, ptext + pos, x - pos + 1);
				if (ttmp[x - pos] == '\n')
					ttmp[x - pos] = 0;
				ttmp[x - pos + 1] = 0;
				wordwrap_print_echostr(ttmp, echostr);
				free(ttmp);
			} else if (ptext[x] == '\n') {
				ttmp = malloc(x - pos + 1);
				strncpy(ttmp, ptext + pos, x - pos);
				ttmp[x - pos] = 0;
				wordwrap_print_echostr(ttmp, echostr);
				free(ttmp);
				break;
			}
		}
		pos = x + 1;
	}
}

==> bsflite-0.81.tar.gz: bsflite-0.81/out.c <==
/**
 ** bsflite - bs-free AIM client
 **
 ** (C) 2003-2005 by Claudio Leite <leitec at leitec dot org>
 **
 ** NO WARRANTY. Read the file COPYING for more details.
 **/

#include "bsf.h"
#include <stdio.h>
#include <sys/time.h>
#ifdef PLAN9
#include <time.h>
#endif
#include <stdlib.h>
#include <string.h>

#ifdef __MINGW32__
#include <windows.h>
#else
#include <termios.h>
#include <sys/ioctl.h>
#endif

#ifdef __DJGPP__
#include <conio.h>
#endif

extern char     inputbuf[512];
extern int      screen_cols;
extern int      screen_lines;
extern int      prompt_len;
extern struct BuddyList *buddylist;
extern struct Conn *conn;

#ifdef __MINGW32__
HANDLE          hOut;
#endif

/* PROTO */
void
addts(void)
{
	char            ts[11];
	struct tm      *now;
	time_t          t;

#ifdef COLOR
	set_color(COLOR_TIMESTAMP);
#endif

	t = time(0);
	now = localtime(&t);
	strftime(ts, 11, "[%H:%M:%S]", now);
	printf("%s", ts);

#ifdef COLOR
	set_color(0);
#endif
	return;
}

#if !defined(PLAN9)
#define TERMINAL_HIJINX
#endif

#ifdef TERMINAL_HIJINX

#ifdef __MINGW32__
#define TERMINAL_WINDOWS
#else

#ifdef __DJGPP__
#define TERMINAL_CONIO
#else
#define TERMINAL_VT100
#endif

#endif

#endif

/* PROTO */
void
eraseline(void)
{
	int             linelen = strlen(inputbuf) + prompt_len;
#ifdef TERMINAL_HIJINX
	int             numcols, numrows, x;
#ifdef TERMINAL_CONIO
	int             desiredx, desiredy;
#endif

#ifdef TERMINAL_WINDOWS
	COORD           nPos;
	CONSOLE_SCREEN_BUFFER_INFO wInfo;
	get_screen_size();
#endif

	numrows = linelen / screen_cols;
	numcols = linelen % screen_cols;

#ifdef TERMINAL_VT100
	if (numrows > 0)
		printf("\033[%dA", numrows);

	if (numcols > 0)
		printf("\033[%dD", numcols);
#endif
#ifdef TERMINAL_WINDOWS
	GetConsoleScreenBufferInfo(hOut, &wInfo);

	nPos.X = wInfo.dwCursorPosition.X - numcols;
	nPos.Y = wInfo.dwCursorPosition.Y - numrows;

	SetConsoleCursorPosition(hOut, nPos);
#endif

#ifdef TERMINAL_CONIO
	desiredx = wherex() - numcols;
	desiredy = wherey() - numrows;

	gotoxy(desiredx, desiredy);
#endif

	for (x = 0; x < linelen; x++)
		putchar(' ');

#ifdef TERMINAL_VT100
	if (numrows > 0)
		printf("\033[%dA", numrows);

	if (numcols > 0)
		printf("\033[%dD", numcols);
#endif
#ifdef TERMINAL_WINDOWS
	GetConsoleScreenBufferInfo(hOut, &wInfo);

	nPos.X = wInfo.dwCursorPosition.X - numcols;
	nPos.Y = wInfo.dwCursorPosition.Y - numrows;

	SetConsoleCursorPosition(hOut, nPos);
#endif
#ifdef TERMINAL_CONIO
	fflush(stdout);

	gotoxy(desiredx, desiredy);
#endif

#else
	int             x;

#ifdef PLAN9
	get_screen_size();
#endif

	for (x = 0; x < linelen; x++)
		printf("\b \b");
#endif

#ifdef COLOR
	set_color(0);
#endif
}

/* PROTO */
void
get_screen_size(void)
{
#if defined(__MINGW32__) || defined(__DJGPP__) || defined(PLAN9)
#ifdef __MINGW32__
	CONSOLE_SCREEN_BUFFER_INFO p;

	GetConsoleScreenBufferInfo(hOut, &p);

	screen_cols = (int) p.dwSize.X;
	screen_lines = (int) p.dwSize.Y;
#endif

#ifdef PLAN9
	screen_cols = getwidth();
	screen_lines = 25;
#endif

#ifdef __DJGPP__
	struct text_info *ti;

	gettextinfo(ti);

	screen_cols = ti->screenwidth;
	screen_lines = ti->screenheight;
#endif
#else
	struct winsize  scrsize;

	ioctl(fileno(stdin), TIOCGWINSZ, &scrsize);
	screen_cols = scrsize.ws_col;
	screen_lines = scrsize.ws_row;
#endif
}

/* PROTO */
void
wordwrap_print(char *str, int offset)
{
	char           *linebuf = NULL;
	char           *curline;
	int             firstline = 1;
	int             xx = 0, yy, jj;

#ifdef __MINGW32__
	get_screen_size();
#endif

	curline = str;

	for (;;) {
		if (curline[xx] == 0)
			break;
		if (curline[xx] != ' ' && (curline[xx] != '\n')) {
			xx++;
			continue;
		}
		yy = xx + 1;
		while ((curline[yy] != ' ') && (curline[yy] != '\n')
		       && (curline[yy] != 0))
			yy++;

		if ((curline[xx] == '\n') || (yy > (screen_cols - offset - 4))) {
			linebuf = malloc(xx + 1);

			strncpy(linebuf, curline, xx);
			linebuf[xx] = 0;

			if (!firstline) {
				for (jj = 0; jj < offset; jj++)
					putchar(' ');
			} else {
				firstline = 0;
			}

			printf("%s\n", linebuf);
			curline += xx + 1;
			xx = 0;

			free(linebuf);

			continue;
		}
		xx++;
	}

	if (!firstline)
		for (jj = 0; jj < offset; jj++)
			putchar(' ');

	printf("%s\n", curline);
}

/* PROTO */
void
wordwrap_print_echostr(char *str, char *echostr)
{
	char           *linebuf = NULL;
	char           *curline;
	int             offset;
	int             xx = 0, yy;

#ifdef __MINGW32__
	get_screen_size();
#endif

	offset = strlen(echostr) + 1;
	curline = str;

	for (;;) {
		if (curline[xx] == 0)
			break;
		if (curline[xx] != ' ') {
			xx++;
			continue;
		}
		yy = xx + 1;
		while (curline[yy] != ' ')
			if (curline[yy] == 0)
				break;
			else
				yy++;

		if (yy > (screen_cols - offset - 3)) {
			linebuf = malloc(xx + 1);

			strncpy(linebuf, curline, xx);
			linebuf[xx] = 0;

			printf("%s %s\n", echostr, linebuf);
			curline += xx + 1;
			xx = 0;

			free(linebuf);
			continue;
		}
		xx++;
	}

	printf("%s %s\n", echostr, curline);
}

#ifdef COLOR
/* PROTO */
void
set_color(int color)
{
	int             bd, fg;
#ifdef COLOR_DARKBG
	int             bg;
#endif

	if (color == 0) {
		printf("\E[0m");
		fflush(stdout);
		return;
	}
	bd = color / 100;
	fg = color % 100;
#ifdef COLOR_DARKBG
	bg = (color % 100) / 10;

	printf("\E[%d;3%d;4%dm", bd, fg, bg);
#else
	printf("\E[%d;3%dm", bd, fg);
#endif
	fflush(stdout);
}
#endif

/* PROTO */
void
display_buddylist(void)
{
	struct BuddyList *trav;
	long            days, hours, minutes;

	for (trav = buddylist; trav != NULL; trav = trav->next) {
		printf("%s ", BUDDYLIST_ECHOSTR);

		if (trav->idle && trav->away)
			printf("%s", BUDDYLIST_GONE);
		else if (trav->idle)
			printf("%s", BUDDYLIST_IDLE);
		else if (trav->away)
			printf("%s", BUDDYLIST_AWAY);
		else
			printf("%s", BUDDYLIST_ONLINE);

		printf(" %-16s", trav->formattedsn);

		if (trav->idle) {
			days = trav->idletime / 1440;
			hours = (trav->idletime % 1440) / 60;
			minutes = trav->idletime % 60;
			printf("  (");
			if (days > 0)
				printf("%ld days, ", days);
			if (hours > 0)
				printf("%02ldh", hours);

			printf("%02ldm)", minutes);
		}
		printf("\n");
	}
}

#define p_echostr() {if(col == 1) printf("%s", BUDDYLIST_ECHOSTR);}

/* PROTO */
void
display_buddylist_sorted(void)
{
	struct BuddyList *trav;
	char            sncopy[17];
	int             run, col;
	int             numcols;


#ifdef __MINGW32__
	get_screen_size();
#endif

	numcols = (screen_cols / 24) - 1;

	if (numcols <= 0)
		numcols = 1;

	for (run = 0, col = 1; run < 4; run++) {
		for (trav = buddylist; trav != NULL; trav = trav->next) {
			if (run == 0) {
				if (!trav->idle && !trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_ONLINE);
				} else {
					continue;
				}
			} else if (run == 1) {
				if (trav->idle && !trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_IDLE);
				} else {
					continue;
				}
			} else if (run == 2) {
				if (!trav->idle && trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_AWAY);
				} else {
					continue;
				}
			} else {
				if (trav->idle && trav->away) {
					p_echostr();
					printf(" %s", BUDDYLIST_GONE);
				} else {
					continue;
				}
			}

			memset(sncopy, 0, sizeof(sncopy));

			if (strlen(trav->formattedsn) > 16) {
				memcpy(sncopy, trav->formattedsn, 13);
#ifdef __OpenBSD__
				strlcat(sncopy, "...", sizeof(sncopy));
#else
				strcat(sncopy, "...");
#endif
			} else {
				memcpy(sncopy, trav->formattedsn, strlen(trav->formattedsn));
			}

			if (col < numcols) {
				printf(" %-16s  ", sncopy);
				col++;
			} else {
				printf(" %s\n", sncopy);
				col = 1;
			}
		}

		if (col != 1)
			printf("\n");

		col = 1;
	}
}

/* PROTO */
void
printspaces(int num)
{
	int             jj;

	for (jj = 0; jj < num; jj++)
		putchar(' ');
}

/* PROTO */
void
prettyprint(char *ptext, int offset)
{
	int             pos, x;
	char           *ttmp;

	pos = 0;
	while (pos < strlen(ptext)) {
		for (x = pos; x < strlen(ptext); x++) {
			if (x == strlen(ptext) - 1) {
				ttmp = malloc(x - pos + 2);
				strncpy(ttmp, ptext + pos, x - pos + 1);
				if (ttmp[x - pos] == '\n')
					ttmp[x - pos] = 0;

				ttmp[x - pos + 1] = 0;
				if (pos != 0)
					printspaces(offset);

				wordwrap_print(ttmp, offset);
				free(ttmp);
			} else if (ptext[x] == '\n') {
				ttmp = malloc(x - pos + 1);
				strncpy(ttmp, ptext + pos, x - pos);
				ttmp[x - pos] = 0;

				if (pos != 0)
					printspaces(offset);
				wordwrap_print(ttmp, offset);
				free(ttmp);
				break;
			}
		}
		pos = x + 1;
	}
}


/* PROTO */
void
prettyprint_echostr(char *ptext, char *echostr)
{
	int             pos, x;
	char           *ttmp;

	pos = 0;
	while (pos < strlen(ptext)) {
		for (x = pos; x < strlen(ptext); x++) {
			if (x == strlen(ptext) - 1) {
				ttmp = malloc(x - pos + 2);
				strncpy(ttmp, ptext + pos, x - pos + 1);
				if (ttmp[x - pos] == '\n')
					ttmp[x - pos] = 0;
				ttmp[x - pos + 1] = 0;
				wordwrap_print_echostr(ttmp, echostr);
				free(ttmp);
			} else if (ptext[x] == '\n') {
				ttmp = malloc(x - pos + 1);
				strncpy(ttmp, ptext + pos, x - pos);
				ttmp[x - pos] = 0;
				wordwrap_print_echostr(ttmp, echostr);
				free(ttmp);
				break;
			}
		}
		pos = x + 1;
	}
}

/* PROTO */
void
set_title(char *title)
{
	char           *termtype = getenv("TERM");

	if (conn->windowtitle != NULL)
		free(conn->windowtitle);

	if (strncmp(termtype, "xterm", 5) == 0) {
		printf("\033]0;%s\007", title);
	} else if (strncmp(termtype, "screen", 6) == 0) {
		printf("\033_%s\033\\", title);
	}
	conn->windowtitle = strdup(title);

	fflush(stdout);
}
